@@ -2,8 +2,8 @@
 
 import logging
 
-import django_filters.fields
 import graphene
+import graphene_django_optimizer as gql_optimizer
 from graphql import GraphQLError
 from graphene_django import DjangoObjectType
 
@@ -53,6 +53,41 @@ def generate_null_choices_resolver(name, resolver_name):
     return resolve_fields_w_choices
 
 
+def generate_filter_resolver(schema_type, resolver_name, field_name):
+    """
+    Generate function to resolve OneToMany filtering.
+
+    Args:
+        schema_type (DjangoObjectType): DjangoObjectType for a given model
+        resolver_name (str): name of the resolver
+        field_name (str): name of OneToMany field to filter
+    """
+    filterset_class = schema_type._meta.filterset_class
+
+    def resolve_filter(self, *args, **kwargs):
+        if not filterset_class:
+            return getattr(self, field_name).all()
+
+        resolved_obj = filterset_class(kwargs, getattr(self, field_name).all())
+
+        # Check result filter for errors.
+        if not resolved_obj.errors:
+            return resolved_obj.qs.all()
+
+        errors = {}
+
+        # Build error message from results
+        # Error messages are collected from each filter object
+        for key in resolved_obj.errors:
+            errors[key] = resolved_obj.errors[key]
+
+        # Raising this exception will send the error message in the response of the GraphQL request
+        raise GraphQLError(errors)
+
+    resolve_filter.__name__ = resolver_name
+    return resolve_filter
+
+
 def generate_custom_field_resolver(name, resolver_name):
     """Generate function to resolve each custom field within each DjangoObjectType.
 
@@ -90,7 +125,7 @@ def generate_relationship_resolver(name, resolver_name, relationship, side, peer
         name (str): name of the custom field to resolve
         resolver_name (str): name of the resolver as declare in DjangoObjectType
         relationship (Relationship): Relationship object to generate a resolver for
-        site (site): side of the relationship to use for the resolver
+        side (str): side of the relationship to use for the resolver
         peer_model (Model): Django Model of the peer of this relationship
     """
 
@@ -98,13 +133,35 @@ def generate_relationship_resolver(name, resolver_name, relationship, side, peer
         """Return a queryset or an object depending on the type of the relationship."""
         peer_side = RelationshipSideChoices.OPPOSITE[side]
         query_params = {"relationship": relationship}
-        query_params[f"{side}_id"] = self.pk
-        queryset_ids = RelationshipAssociation.objects.filter(**query_params).values_list(f"{peer_side}_id", flat=True)
+        if not relationship.symmetric:
+            # Get the objects on the other side of this relationship
+            query_params[f"{side}_id"] = self.pk
+            queryset_ids = gql_optimizer.query(
+                RelationshipAssociation.objects.filter(**query_params).values_list(f"{peer_side}_id", flat=True), info
+            )
+        else:
+            # Get objects that are peers for this relationship, regardless of side
+            queryset_ids = list(
+                gql_optimizer.query(
+                    RelationshipAssociation.objects.filter(source_id=self.pk, **query_params).values_list(
+                        "destination_id", flat=True
+                    ),
+                    info,
+                )
+            )
+            queryset_ids += list(
+                gql_optimizer.query(
+                    RelationshipAssociation.objects.filter(destination_id=self.pk, **query_params).values_list(
+                        "source_id", flat=True
+                    ),
+                    info,
+                )
+            )
 
         if relationship.has_many(peer_side):
-            return peer_model.objects.filter(id__in=queryset_ids)
+            return gql_optimizer.query(peer_model.objects.filter(id__in=queryset_ids), info)
 
-        return peer_model.objects.filter(id__in=queryset_ids).first()
+        return gql_optimizer.query(peer_model.objects.filter(id__in=queryset_ids).first(), info)
 
     resolve_relationship.__name__ = resolver_name
     return resolve_relationship
@@ -178,7 +235,9 @@ def generate_single_item_resolver(schema_type, resolver_name):
 
         obj_id = kwargs.get("id", None)
         if obj_id:
-            return model.objects.restrict(info.context.user, "view").get(pk=obj_id)
+            return gql_optimizer.query(
+                model.objects.restrict(info.context.user, "view").filter(pk=obj_id), info
+            ).first()
         return None
 
     single_resolver.__name__ = resolver_name
@@ -219,9 +278,9 @@ def generate_list_resolver(schema_type, resolver_name):
                 # Raising this exception will send the error message in the response of the GraphQL request
                 raise GraphQLError(errors)
 
-            return resolved_obj.qs.all()
+            return gql_optimizer.query(resolved_obj.qs.all(), info)
 
-        return model.objects.restrict(info.context.user, "view").all()
+        return gql_optimizer.query(model.objects.restrict(info.context.user, "view").all(), info)
 
     list_resolver.__name__ = resolver_name
     return list_resolver
