@@ -1,7 +1,8 @@
+from copy import deepcopy
 import logging
 import re
-from copy import deepcopy
 
+from django.conf import settings
 from django.contrib import messages
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import (
@@ -14,6 +15,7 @@ from django.db.models import ManyToManyField, ProtectedError
 from django.forms import Form, ModelMultipleChoiceField, MultipleHiddenInput, Textarea
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404, redirect, render
+from django.urls import NoReverseMatch, reverse
 from django.utils.html import escape
 from django.utils.http import is_safe_url
 from django.utils.safestring import mark_safe
@@ -28,6 +30,7 @@ from nautobot.utilities.forms import (
     BulkRenameForm,
     ConfirmationForm,
     CSVDataField,
+    CSVFileField,
     ImportForm,
     TableConfigForm,
     restrict_form_fields,
@@ -69,11 +72,41 @@ class ObjectView(ObjectPermissionRequiredMixin, View):
         """
         Return any additional context data for the template.
 
-        request: The current request
-        instance: The object being viewed
+        Args:
+            request: The current request
+            instance: The object being viewed
+
+        Returns:
+            dict
         """
         return {}
 
+    def get_changelog_url(self, instance):
+        """Return the changelog URL for a given instance."""
+        meta = self.queryset.model._meta
+
+        # Don't try to generate a changelog_url for an ObjectChange.
+        if meta.model_name == "objectchange":
+            return None
+
+        route = f"{meta.app_label}:{meta.model_name}_changelog"
+        if meta.app_label in settings.PLUGINS:
+            route = f"plugins:{route}"
+
+        # Iterate the pk-like fields and try to get a URL, or return None.
+        fields = ["pk", "slug"]
+        for field in fields:
+            if not hasattr(instance, field):
+                continue
+
+            try:
+                return reverse(route, kwargs={field: getattr(instance, field)})
+            except NoReverseMatch:
+                continue
+
+        # This object likely doesn't have a changelog route defined.
+        return None
+
     def get(self, request, *args, **kwargs):
         """
         Generic GET handler for accessing an object by PK or slug
@@ -85,6 +118,9 @@ class ObjectView(ObjectPermissionRequiredMixin, View):
             self.get_template_name(),
             {
                 "object": instance,
+                "verbose_name": self.queryset.model._meta.verbose_name,
+                "verbose_name_plural": self.queryset.model._meta.verbose_name_plural,
+                "changelog_url": self.get_changelog_url(instance),
                 **self.get_extra_context(request, instance),
             },
         )
@@ -246,14 +282,26 @@ class ObjectEditView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
         return get_permission_for_model(self.queryset.model, self._permission_action)
 
     def get_object(self, kwargs):
-        # Look up an existing object by slug or PK, if provided.
-        if "slug" in kwargs:
-            return get_object_or_404(self.queryset, slug=kwargs["slug"])
-        elif "pk" in kwargs:
-            return get_object_or_404(self.queryset, pk=kwargs["pk"])
-        # Otherwise, return a new instance.
+        """Retrieve an object based on `kwargs`."""
+        # Look up an existing object by slug, PK, or name, if provided.
+        for field in ("slug", "pk", "name"):
+            if field in kwargs:
+                return get_object_or_404(self.queryset, **{field: kwargs[field]})
         return self.queryset.model()
 
+    def get_extra_context(self, request, instance):
+        """
+        Return any additional context data for the template.
+
+        Args:
+            request: The current request
+            instance: The object being edited
+
+        Returns:
+            dict
+        """
+        return {}
+
     def alter_obj(self, obj, request, url_args, url_kwargs):
         # Allow views to add extra info to an object before it is processed. For example, a parent object can be defined
         # given some parameter from the request URL.
@@ -281,6 +329,7 @@ class ObjectEditView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
                 "form": form,
                 "return_url": self.get_return_url(request, obj),
                 "editing": obj.present_in_database,
+                **self.get_extra_context(request, obj),
             },
         )
 
@@ -344,6 +393,7 @@ class ObjectEditView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
                 "form": form,
                 "return_url": self.get_return_url(request, obj),
                 "editing": obj.present_in_database,
+                **self.get_extra_context(request, obj),
             },
         )
 
@@ -363,11 +413,12 @@ class ObjectDeleteView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
         return get_permission_for_model(self.queryset.model, "delete")
 
     def get_object(self, kwargs):
-        # Look up object by slug if one has been provided. Otherwise, use PK.
-        if "slug" in kwargs:
-            return get_object_or_404(self.queryset, slug=kwargs["slug"])
-        else:
-            return get_object_or_404(self.queryset, pk=kwargs["pk"])
+        """Retrieve an object based on `kwargs`."""
+        # Look up an existing object by slug or PK, or name if provided.
+        for field in ("slug", "pk", "name"):
+            if field in kwargs:
+                return get_object_or_404(self.queryset, **{field: kwargs[field]})
+        return self.queryset.model()
 
     def get(self, request, **kwargs):
         obj = self.get_object(kwargs)
@@ -700,7 +751,8 @@ class BulkImportView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
 
     def _import_form(self, *args, **kwargs):
         class ImportForm(BootstrapMixin, Form):
-            csv = CSVDataField(from_form=self.model_form, widget=Textarea(attrs=self.widget_attrs))
+            csv_data = CSVDataField(from_form=self.model_form, widget=Textarea(attrs=self.widget_attrs))
+            csv_file = CSVFileField(from_form=self.model_form)
 
         return ImportForm(*args, **kwargs)
 
@@ -723,13 +775,14 @@ class BulkImportView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
                 "fields": self.model_form().fields,
                 "obj_type": self.model_form._meta.model._meta.verbose_name,
                 "return_url": self.get_return_url(request),
+                "active_tab": "csv-data",
             },
         )
 
     def post(self, request):
         logger = logging.getLogger("nautobot.views.BulkImportView")
         new_objs = []
-        form = self._import_form(request.POST)
+        form = self._import_form(request.POST, request.FILES)
 
         if form.is_valid():
             logger.debug("Form validation was successful")
@@ -737,7 +790,11 @@ class BulkImportView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
             try:
                 # Iterate through CSV data and bind each row to a new model form instance.
                 with transaction.atomic():
-                    headers, records = form.cleaned_data["csv"]
+                    if request.FILES:
+                        field_name = "csv_file"
+                    else:
+                        field_name = "csv_data"
+                    headers, records = form.cleaned_data[field_name]
                     for row, data in enumerate(records, start=1):
                         obj_form = self.model_form(data, headers=headers)
                         restrict_form_fields(obj_form, request.user)
@@ -747,7 +804,7 @@ class BulkImportView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
                             new_objs.append(obj)
                         else:
                             for field, err in obj_form.errors.items():
-                                form.add_error("csv", "Row {} {}: {}".format(row, field, err[0]))
+                                form.add_error(field_name, "Row {} {}: {}".format(row, field, err[0]))
                             raise ValidationError("")
 
                     # Enforce object-level permissions
@@ -790,6 +847,7 @@ class BulkImportView(GetReturnURLMixin, ObjectPermissionRequiredMixin, View):
                 "fields": self.model_form().fields,
                 "obj_type": self.model_form._meta.model._meta.verbose_name,
                 "return_url": self.get_return_url(request),
+                "active_tab": "csv-file" if form.has_error("csv_file") else "csv-data",
             },
         )
 
