@@ -14,7 +14,13 @@ from nautobot.utilities.filters import (
     TagFilter,
 )
 from nautobot.virtualization.models import Cluster, ClusterGroup
-from .choices import *
+from .choices import (
+    CustomFieldFilterLogicChoices,
+    CustomFieldTypeChoices,
+    JobResultStatusChoices,
+    SecretsGroupAccessTypeChoices,
+    SecretsGroupSecretTypeChoices,
+)
 from .models import (
     ComputedField,
     ConfigContext,
@@ -26,10 +32,14 @@ from .models import (
     GitRepository,
     GraphQLQuery,
     ImageAttachment,
+    ScheduledJob,
     JobResult,
     ObjectChange,
     Relationship,
     RelationshipAssociation,
+    Secret,
+    SecretsGroup,
+    SecretsGroupAssociation,
     Status,
     Tag,
     Webhook,
@@ -37,6 +47,7 @@ from .models import (
 
 
 __all__ = (
+    "ComputedFieldFilterSet",
     "ConfigContextFilterSet",
     "ContentTypeFilterSet",
     "CreatedUpdatedFilterSet",
@@ -52,6 +63,10 @@ __all__ = (
     "ObjectChangeFilterSet",
     "RelationshipFilterSet",
     "RelationshipAssociationFilterSet",
+    "ScheduledJobFilterSet",
+    "SecretFilterSet",
+    "SecretsGroupFilterSet",
+    "SecretsGroupAssociationFilterSet",
     "StatusFilter",
     "StatusFilterSet",
     "StatusModelFilterSetMixin",
@@ -59,134 +74,58 @@ __all__ = (
     "WebhookFilterSet",
 )
 
-EXACT_FILTER_TYPES = (
-    CustomFieldTypeChoices.TYPE_BOOLEAN,
-    CustomFieldTypeChoices.TYPE_DATE,
-    CustomFieldTypeChoices.TYPE_INTEGER,
-    CustomFieldTypeChoices.TYPE_SELECT,
-    CustomFieldTypeChoices.TYPE_MULTISELECT,
-)
+
+#
+# Mixins
+#
 
 
-class CustomFieldFilter(django_filters.Filter):
-    """
-    Filter objects by the presence of a CustomFieldValue. The filter's name is used as the CustomField name.
-    """
-
-    def __init__(self, custom_field, *args, **kwargs):
-        self.custom_field = custom_field
-
-        if custom_field.type == CustomFieldTypeChoices.TYPE_INTEGER:
-            self.field_class = IntegerField
-        elif custom_field.type == CustomFieldTypeChoices.TYPE_BOOLEAN:
-            self.field_class = NullBooleanField
-        elif custom_field.type == CustomFieldTypeChoices.TYPE_DATE:
-            self.field_class = DateField
-
-        super().__init__(*args, **kwargs)
-
-        self.field_name = f"_custom_field_data__{self.field_name}"
-
-        if custom_field.type not in EXACT_FILTER_TYPES:
-            if custom_field.filter_logic == CustomFieldFilterLogicChoices.FILTER_LOOSE:
-                self.lookup_expr = "icontains"
-
-        elif custom_field.type == CustomFieldTypeChoices.TYPE_MULTISELECT:
-            # Contains handles lists within the JSON data for multi select fields
-            self.lookup_expr = "contains"
+class CreatedUpdatedFilterSet(django_filters.FilterSet):
+    created = django_filters.DateFilter()
+    created__gte = django_filters.DateFilter(field_name="created", lookup_expr="gte")
+    created__lte = django_filters.DateFilter(field_name="created", lookup_expr="lte")
+    last_updated = django_filters.DateTimeFilter()
+    last_updated__gte = django_filters.DateTimeFilter(field_name="last_updated", lookup_expr="gte")
+    last_updated__lte = django_filters.DateTimeFilter(field_name="last_updated", lookup_expr="lte")
 
 
-class CustomFieldModelFilterSet(django_filters.FilterSet):
-    """
-    Dynamically add a Filter for each CustomField applicable to the parent model.
-    """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-        custom_fields = CustomField.objects.filter(
-            content_types=ContentType.objects.get_for_model(self._meta.model)
-        ).exclude(filter_logic=CustomFieldFilterLogicChoices.FILTER_DISABLED)
-        for cf in custom_fields:
-            self.filters["cf_{}".format(cf.name)] = CustomFieldFilter(field_name=cf.name, custom_field=cf)
+#
+# Computed Fields
+#
 
 
-class CustomFieldFilterSet(BaseFilterSet):
+class ComputedFieldFilterSet(BaseFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
-    content_types = ContentTypeMultipleChoiceFilter(
-        choices=FeatureQuery("custom_fields").get_choices,
-    )
+    content_type = ContentTypeFilter()
 
     class Meta:
-        model = CustomField
-        fields = ["id", "content_types", "name", "required", "filter_logic", "weight"]
-
-    def search(self, queryset, name, value):
-        if not value.strip():
-            return queryset
-        return queryset.filter(Q(name__icontains=value) | Q(label__icontains=value))
-
-
-class CustomFieldChoiceFilterSet(BaseFilterSet):
-    q = django_filters.CharFilter(
-        method="search",
-        label="Search",
-    )
-    field_id = django_filters.ModelMultipleChoiceFilter(
-        field_name="field",
-        queryset=CustomField.objects.all(),
-        label="Field",
-    )
-    field = django_filters.ModelMultipleChoiceFilter(
-        field_name="field__name",
-        queryset=CustomField.objects.all(),
-        to_field_name="name",
-        label="Field (name)",
-    )
-
-    class Meta:
-        model = CustomFieldChoice
-        fields = ["id", "value", "weight"]
-
-    def search(self, queryset, name, value):
-        if not value.strip():
-            return queryset
-        return queryset.filter(Q(value__icontains=value))
-
-
-class ExportTemplateFilterSet(BaseFilterSet):
-    q = django_filters.CharFilter(
-        method="search",
-        label="Search",
-    )
-    owner_content_type = ContentTypeFilter()
-
-    class Meta:
-        model = ExportTemplate
-        fields = ["id", "content_type", "owner_content_type", "owner_object_id", "name"]
+        model = ComputedField
+        fields = (
+            "content_type",
+            "slug",
+            "template",
+            "fallback_value",
+            "weight",
+        )
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
         return queryset.filter(
             Q(name__icontains=value)
-            | Q(owner_content_type__app_label__icontains=value)
-            | Q(owner_content_type__model__icontains=value)
+            | Q(target_url__icontains=value)
+            | Q(text__icontains=value)
             | Q(content_type__app_label__icontains=value)
             | Q(content_type__model__icontains=value)
-            | Q(description__icontains=value)
         )
 
 
-class ImageAttachmentFilterSet(BaseFilterSet):
-    content_type = ContentTypeFilter()
-
-    class Meta:
-        model = ImageAttachment
-        fields = ["id", "content_type_id", "object_id", "name"]
+#
+# Config Contexts
+#
 
 
 class ConfigContextFilterSet(BaseFilterSet):
@@ -305,31 +244,6 @@ class ConfigContextFilterSet(BaseFilterSet):
         return queryset.filter(Q(name__icontains=value) | Q(description__icontains=value) | Q(data__icontains=value))
 
 
-#
-# Filter for Local Config Context Data
-#
-
-
-class LocalContextFilterSet(django_filters.FilterSet):
-    local_context_data = django_filters.BooleanFilter(
-        method="_local_context_data",
-        label="Has local config context data",
-    )
-    local_context_schema_id = django_filters.ModelMultipleChoiceFilter(
-        queryset=ConfigContextSchema.objects.all(),
-        label="Schema (ID)",
-    )
-    local_context_schema = django_filters.ModelMultipleChoiceFilter(
-        field_name="local_context_schema__slug",
-        queryset=ConfigContextSchema.objects.all(),
-        to_field_name="slug",
-        label="Schema (slug)",
-    )
-
-    def _local_context_data(self, queryset, name, value):
-        return queryset.exclude(local_context_data__isnull=value)
-
-
 #
 # Filter for config context schema
 #
@@ -358,77 +272,6 @@ class ConfigContextSchemaFilterSet(BaseFilterSet):
         )
 
 
-class ObjectChangeFilterSet(BaseFilterSet):
-    q = django_filters.CharFilter(
-        method="search",
-        label="Search",
-    )
-    time = django_filters.DateTimeFromToRangeFilter()
-    changed_object_type = ContentTypeFilter()
-    user_id = django_filters.ModelMultipleChoiceFilter(
-        queryset=get_user_model().objects.all(),
-        label="User (ID)",
-    )
-    user = django_filters.ModelMultipleChoiceFilter(
-        field_name="user__username",
-        queryset=get_user_model().objects.all(),
-        to_field_name="username",
-        label="User name",
-    )
-
-    class Meta:
-        model = ObjectChange
-        fields = [
-            "id",
-            "user",
-            "user_name",
-            "request_id",
-            "action",
-            "changed_object_type_id",
-            "changed_object_id",
-            "object_repr",
-        ]
-
-    def search(self, queryset, name, value):
-        if not value.strip():
-            return queryset
-        return queryset.filter(Q(user_name__icontains=value) | Q(object_repr__icontains=value))
-
-
-class CreatedUpdatedFilterSet(django_filters.FilterSet):
-    created = django_filters.DateFilter()
-    created__gte = django_filters.DateFilter(field_name="created", lookup_expr="gte")
-    created__lte = django_filters.DateFilter(field_name="created", lookup_expr="lte")
-    last_updated = django_filters.DateTimeFilter()
-    last_updated__gte = django_filters.DateTimeFilter(field_name="last_updated", lookup_expr="gte")
-    last_updated__lte = django_filters.DateTimeFilter(field_name="last_updated", lookup_expr="lte")
-
-
-#
-# Job Results
-#
-
-
-class JobResultFilterSet(BaseFilterSet):
-    q = django_filters.CharFilter(
-        method="search",
-        label="Search",
-    )
-    obj_type = ContentTypeFilter()
-    created = django_filters.DateTimeFilter()
-    completed = django_filters.DateTimeFilter()
-    status = django_filters.MultipleChoiceFilter(choices=JobResultStatusChoices, null_value=None)
-
-    class Meta:
-        model = JobResult
-        fields = ["id", "created", "completed", "status", "user", "obj_type", "name"]
-
-    def search(self, queryset, name, value):
-        if not value.strip():
-            return queryset
-        return queryset.filter(Q(name__icontains=value) | Q(user__username__icontains=value))
-
-
 #
 # ContentTypes
 #
@@ -441,51 +284,106 @@ class ContentTypeFilterSet(django_filters.FilterSet):
 
 
 #
-# Tags
+# Custom Fields
 #
 
 
-class TagFilterSet(BaseFilterSet, CreatedUpdatedFilterSet, CustomFieldModelFilterSet):
+EXACT_FILTER_TYPES = (
+    CustomFieldTypeChoices.TYPE_BOOLEAN,
+    CustomFieldTypeChoices.TYPE_DATE,
+    CustomFieldTypeChoices.TYPE_INTEGER,
+    CustomFieldTypeChoices.TYPE_SELECT,
+    CustomFieldTypeChoices.TYPE_MULTISELECT,
+)
+
+
+class CustomFieldFilter(django_filters.Filter):
+    """
+    Filter objects by the presence of a CustomFieldValue. The filter's name is used as the CustomField name.
+    """
+
+    def __init__(self, custom_field, *args, **kwargs):
+        self.custom_field = custom_field
+
+        if custom_field.type == CustomFieldTypeChoices.TYPE_INTEGER:
+            self.field_class = IntegerField
+        elif custom_field.type == CustomFieldTypeChoices.TYPE_BOOLEAN:
+            self.field_class = NullBooleanField
+        elif custom_field.type == CustomFieldTypeChoices.TYPE_DATE:
+            self.field_class = DateField
+
+        super().__init__(*args, **kwargs)
+
+        self.field_name = f"_custom_field_data__{self.field_name}"
+
+        if custom_field.type not in EXACT_FILTER_TYPES:
+            if custom_field.filter_logic == CustomFieldFilterLogicChoices.FILTER_LOOSE:
+                self.lookup_expr = "icontains"
+
+        elif custom_field.type == CustomFieldTypeChoices.TYPE_MULTISELECT:
+            # Contains handles lists within the JSON data for multi select fields
+            self.lookup_expr = "contains"
+
+
+class CustomFieldModelFilterSet(django_filters.FilterSet):
+    """
+    Dynamically add a Filter for each CustomField applicable to the parent model.
+    """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        custom_fields = CustomField.objects.filter(
+            content_types=ContentType.objects.get_for_model(self._meta.model)
+        ).exclude(filter_logic=CustomFieldFilterLogicChoices.FILTER_DISABLED)
+        for cf in custom_fields:
+            self.filters["cf_{}".format(cf.name)] = CustomFieldFilter(field_name=cf.name, custom_field=cf)
+
+
+class CustomFieldFilterSet(BaseFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
+    content_types = ContentTypeMultipleChoiceFilter(
+        choices=FeatureQuery("custom_fields").get_choices,
+    )
 
     class Meta:
-        model = Tag
-        fields = ["id", "name", "slug", "color"]
+        model = CustomField
+        fields = ["id", "content_types", "name", "required", "filter_logic", "weight"]
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
-        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value))
+        return queryset.filter(Q(name__icontains=value) | Q(label__icontains=value) | Q(description__icontains=value))
 
 
-#
-# Datasources
-#
-
-
-class GitRepositoryFilterSet(BaseFilterSet, CreatedUpdatedFilterSet, CustomFieldModelFilterSet):
+class CustomFieldChoiceFilterSet(BaseFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
-    tag = TagFilter()
+    field_id = django_filters.ModelMultipleChoiceFilter(
+        field_name="field",
+        queryset=CustomField.objects.all(),
+        label="Field",
+    )
+    field = django_filters.ModelMultipleChoiceFilter(
+        field_name="field__name",
+        queryset=CustomField.objects.all(),
+        to_field_name="name",
+        label="Field (name)",
+    )
 
     class Meta:
-        model = GitRepository
-        fields = ["id", "name", "slug", "remote_url", "branch"]
+        model = CustomFieldChoice
+        fields = ["id", "value", "weight"]
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
-        qs_filter = Q(name__icontains=value) | Q(remote_url__icontains=value) | Q(branch__icontains=value)
-        try:
-            qs_filter |= Q(asn=int(value.strip()))
-        except ValueError:
-            pass
-        return queryset.filter(qs_filter)
+        return queryset.filter(Q(value__icontains=value))
 
 
 #
@@ -526,42 +424,327 @@ class CustomLinkFilterSet(BaseFilterSet):
 
 
 #
-# Webhooks
+# Export Templates
 #
 
 
-class WebhookFilterSet(BaseFilterSet):
+class ExportTemplateFilterSet(BaseFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
-    content_types = ContentTypeMultipleChoiceFilter(
-        choices=FeatureQuery("webhooks").get_choices,
-    )
+    owner_content_type = ContentTypeFilter()
 
     class Meta:
-        model = Webhook
-        fields = [
-            "name",
-            "payload_url",
-            "enabled",
-            "content_types",
-            "type_create",
-            "type_update",
-            "type_delete",
-        ]
+        model = ExportTemplate
+        fields = ["id", "content_type", "owner_content_type", "owner_object_id", "name"]
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
         return queryset.filter(
             Q(name__icontains=value)
-            | Q(payload_url__icontains=value)
-            | Q(additional_headers__icontains=value)
-            | Q(body_template__icontains=value)
+            | Q(owner_content_type__app_label__icontains=value)
+            | Q(owner_content_type__model__icontains=value)
+            | Q(content_type__app_label__icontains=value)
+            | Q(content_type__model__icontains=value)
+            | Q(description__icontains=value)
         )
 
 
+#
+# Datasources (Git)
+#
+
+
+class GitRepositoryFilterSet(BaseFilterSet, CreatedUpdatedFilterSet, CustomFieldModelFilterSet):
+    q = django_filters.CharFilter(
+        method="search",
+        label="Search",
+    )
+    secrets_group_id = django_filters.ModelMultipleChoiceFilter(
+        field_name="secrets_group",
+        queryset=SecretsGroup.objects.all(),
+        label="Secrets group (ID)",
+    )
+    secrets_group = django_filters.ModelMultipleChoiceFilter(
+        field_name="secrets_group__slug",
+        queryset=SecretsGroup.objects.all(),
+        to_field_name="slug",
+        label="Secrets group (slug)",
+    )
+    tag = TagFilter()
+
+    class Meta:
+        model = GitRepository
+        fields = ["id", "name", "slug", "remote_url", "branch"]
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        qs_filter = Q(name__icontains=value) | Q(remote_url__icontains=value) | Q(branch__icontains=value)
+        try:
+            qs_filter |= Q(asn=int(value.strip()))
+        except ValueError:
+            pass
+        return queryset.filter(qs_filter)
+
+
+#
+# GraphQL Queries
+#
+
+
+class GraphQLQueryFilterSet(BaseFilterSet):
+    q = django_filters.CharFilter(
+        method="search",
+        label="Search",
+    )
+
+    class Meta:
+        model = GraphQLQuery
+        fields = (
+            "name",
+            "slug",
+        )
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value) | Q(query__icontains=value))
+
+
+#
+# Image Attachments
+#
+
+
+class ImageAttachmentFilterSet(BaseFilterSet):
+    content_type = ContentTypeFilter()
+
+    class Meta:
+        model = ImageAttachment
+        fields = ["id", "content_type_id", "object_id", "name"]
+
+
+#
+# Jobs
+#
+
+
+class JobResultFilterSet(BaseFilterSet, CustomFieldModelFilterSet):
+    q = django_filters.CharFilter(
+        method="search",
+        label="Search",
+    )
+    obj_type = ContentTypeFilter()
+    created = django_filters.DateTimeFilter()
+    completed = django_filters.DateTimeFilter()
+    status = django_filters.MultipleChoiceFilter(choices=JobResultStatusChoices, null_value=None)
+
+    class Meta:
+        model = JobResult
+        fields = ["id", "created", "completed", "status", "user", "obj_type", "name"]
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(Q(name__icontains=value) | Q(user__username__icontains=value))
+
+
+class ScheduledJobFilterSet(BaseFilterSet):
+    q = django_filters.CharFilter(
+        method="search",
+        label="Search",
+    )
+    first_run = django_filters.DateTimeFilter()
+    last_run = django_filters.DateTimeFilter()
+
+    class Meta:
+        model = ScheduledJob
+        fields = ["id", "first_run", "last_run", "total_run_count"]
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(
+            Q(name__icontains=value) | Q(job_class__icontains=value) | Q(description__icontains=value)
+        )
+
+
+#
+# Filter for Local Config Context Data
+#
+
+
+class LocalContextFilterSet(django_filters.FilterSet):
+    local_context_data = django_filters.BooleanFilter(
+        method="_local_context_data",
+        label="Has local config context data",
+    )
+    local_context_schema_id = django_filters.ModelMultipleChoiceFilter(
+        queryset=ConfigContextSchema.objects.all(),
+        label="Schema (ID)",
+    )
+    local_context_schema = django_filters.ModelMultipleChoiceFilter(
+        field_name="local_context_schema__slug",
+        queryset=ConfigContextSchema.objects.all(),
+        to_field_name="slug",
+        label="Schema (slug)",
+    )
+
+    def _local_context_data(self, queryset, name, value):
+        return queryset.exclude(local_context_data__isnull=value)
+
+
+class ObjectChangeFilterSet(BaseFilterSet):
+    q = django_filters.CharFilter(
+        method="search",
+        label="Search",
+    )
+    time = django_filters.DateTimeFromToRangeFilter()
+    changed_object_type = ContentTypeFilter()
+    user_id = django_filters.ModelMultipleChoiceFilter(
+        queryset=get_user_model().objects.all(),
+        label="User (ID)",
+    )
+    user = django_filters.ModelMultipleChoiceFilter(
+        field_name="user__username",
+        queryset=get_user_model().objects.all(),
+        to_field_name="username",
+        label="User name",
+    )
+
+    class Meta:
+        model = ObjectChange
+        fields = [
+            "id",
+            "user",
+            "user_name",
+            "request_id",
+            "action",
+            "changed_object_type_id",
+            "changed_object_id",
+            "object_repr",
+        ]
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(Q(user_name__icontains=value) | Q(object_repr__icontains=value))
+
+
+#
+# Relationships
+#
+
+
+class RelationshipFilterSet(BaseFilterSet):
+
+    source_type = ContentTypeMultipleChoiceFilter(choices=FeatureQuery("relationships").get_choices, conjoined=False)
+    destination_type = ContentTypeMultipleChoiceFilter(
+        choices=FeatureQuery("relationships").get_choices, conjoined=False
+    )
+
+    class Meta:
+        model = Relationship
+        fields = ["id", "name", "type", "source_type", "destination_type"]
+
+
+class RelationshipAssociationFilterSet(BaseFilterSet):
+
+    relationship = django_filters.ModelMultipleChoiceFilter(
+        field_name="relationship__slug",
+        queryset=Relationship.objects.all(),
+        to_field_name="slug",
+        label="Relationship (slug)",
+    )
+    source_type = ContentTypeMultipleChoiceFilter(choices=FeatureQuery("relationships").get_choices, conjoined=False)
+    destination_type = ContentTypeMultipleChoiceFilter(
+        choices=FeatureQuery("relationships").get_choices, conjoined=False
+    )
+
+    class Meta:
+        model = RelationshipAssociation
+        fields = ["id", "relationship", "source_type", "source_id", "destination_type", "destination_id"]
+
+
+#
+# Secrets
+#
+
+
+class SecretFilterSet(
+    BaseFilterSet,
+    CustomFieldModelFilterSet,
+    CreatedUpdatedFilterSet,
+):
+    """Filterset for the Secret model."""
+
+    q = django_filters.CharFilter(method="search", label="Search")
+    # TODO dynamic choices needed
+    # provider = django_filters.MultipleChoiceFilter(choices=..., null_value=None)
+
+    class Meta:
+        model = Secret
+        fields = ("id", "name", "slug", "provider", "created", "last_updated")
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value))
+
+
+class SecretsGroupFilterSet(
+    BaseFilterSet,
+    CustomFieldModelFilterSet,
+    CreatedUpdatedFilterSet,
+):
+    """Filterset for the SecretsGroup model."""
+
+    q = django_filters.CharFilter(method="search", label="Search")
+
+    class Meta:
+        model = SecretsGroup
+        fields = ("id", "name", "slug", "created", "last_updated")
+
+    def search(self, queryset, name, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value))
+
+
+class SecretsGroupAssociationFilterSet(BaseFilterSet):
+    """Filterset for the SecretsGroupAssociation through model."""
+
+    group_id = django_filters.ModelMultipleChoiceFilter(
+        queryset=SecretsGroup.objects.all(),
+        label="Group (ID)",
+    )
+    group = django_filters.ModelMultipleChoiceFilter(
+        queryset=SecretsGroup.objects.all(),
+        field_name="group__slug",
+        to_field_name="slug",
+        label="Group (slug)",
+    )
+    secret_id = django_filters.ModelMultipleChoiceFilter(
+        queryset=Secret.objects.all(),
+        label="Secret (ID)",
+    )
+    secret = django_filters.ModelMultipleChoiceFilter(
+        queryset=Secret.objects.all(),
+        field_name="secret__slug",
+        to_field_name="slug",
+        label="Secret (slug)",
+    )
+    access_type = django_filters.MultipleChoiceFilter(choices=SecretsGroupAccessTypeChoices)
+    secret_type = django_filters.MultipleChoiceFilter(choices=SecretsGroupSecretTypeChoices)
+
+    class Meta:
+        model = SecretsGroupAssociation
+        fields = ("id",)
+
+
 #
 # Statuses
 #
@@ -632,83 +815,58 @@ class StatusModelFilterSetMixin(django_filters.FilterSet):
 
 
 #
-# Relationship
+# Tags
 #
 
 
-class RelationshipFilterSet(BaseFilterSet):
-
-    source_type = ContentTypeMultipleChoiceFilter(choices=FeatureQuery("relationships").get_choices, conjoined=False)
-    destination_type = ContentTypeMultipleChoiceFilter(
-        choices=FeatureQuery("relationships").get_choices, conjoined=False
-    )
-
-    class Meta:
-        model = Relationship
-        fields = ["id", "name", "type", "source_type", "destination_type"]
-
-
-class RelationshipAssociationFilterSet(BaseFilterSet):
-
-    relationship = django_filters.ModelMultipleChoiceFilter(
-        field_name="relationship__slug",
-        queryset=Relationship.objects.all(),
-        to_field_name="slug",
-        label="Relationship (slug)",
-    )
-    source_type = ContentTypeMultipleChoiceFilter(choices=FeatureQuery("relationships").get_choices, conjoined=False)
-    destination_type = ContentTypeMultipleChoiceFilter(
-        choices=FeatureQuery("relationships").get_choices, conjoined=False
-    )
-
-    class Meta:
-        model = RelationshipAssociation
-        fields = ["id", "relationship", "source_type", "source_id", "destination_type", "destination_id"]
-
-
-class GraphQLQueryFilterSet(BaseFilterSet):
+class TagFilterSet(BaseFilterSet, CreatedUpdatedFilterSet, CustomFieldModelFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
 
     class Meta:
-        model = GraphQLQuery
-        fields = (
-            "name",
-            "slug",
-        )
+        model = Tag
+        fields = ["id", "name", "slug", "color"]
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
-        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value) | Q(query__icontains=value))
+        return queryset.filter(Q(name__icontains=value) | Q(slug__icontains=value))
 
 
-class ComputedFieldFilterSet(BaseFilterSet):
+#
+# Webhooks
+#
+
+
+class WebhookFilterSet(BaseFilterSet):
     q = django_filters.CharFilter(
         method="search",
         label="Search",
     )
-    content_type = ContentTypeFilter()
+    content_types = ContentTypeMultipleChoiceFilter(
+        choices=FeatureQuery("webhooks").get_choices,
+    )
 
     class Meta:
-        model = ComputedField
-        fields = (
-            "content_type",
-            "slug",
-            "template",
-            "fallback_value",
-            "weight",
-        )
+        model = Webhook
+        fields = [
+            "name",
+            "payload_url",
+            "enabled",
+            "content_types",
+            "type_create",
+            "type_update",
+            "type_delete",
+        ]
 
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
         return queryset.filter(
             Q(name__icontains=value)
-            | Q(target_url__icontains=value)
-            | Q(text__icontains=value)
-            | Q(content_type__app_label__icontains=value)
-            | Q(content_type__model__icontains=value)
+            | Q(payload_url__icontains=value)
+            | Q(additional_headers__icontains=value)
+            | Q(body_template__icontains=value)
         )
