@@ -2,7 +2,6 @@ from .change_logging import ChangeLoggedModel, ObjectChange
 from .statuses import Status, StatusField, StatusModel
 from .customfields import ComputedField, CustomField, CustomFieldChoice, CustomFieldModel
 from .datasources import GitRepository
-from .relationships import Relationship, RelationshipModel, RelationshipAssociation
 from .models import (
     ConfigContext,
     ConfigContextModel,
@@ -15,9 +14,14 @@ from .models import (
     HealthCheckTestModel,
     ImageAttachment,
     Job,
+    JobLogEntry,
     JobResult,
+    ScheduledJob,
+    ScheduledJobs,
     Webhook,
 )
+from .relationships import Relationship, RelationshipModel, RelationshipAssociation
+from .secrets import Secret, SecretsGroup, SecretsGroupAssociation
 from .tags import Tag, TaggedItem
 
 __all__ = (
@@ -38,11 +42,17 @@ __all__ = (
     "HealthCheckTestModel",
     "ImageAttachment",
     "Job",
+    "JobLogEntry",
     "JobResult",
     "ObjectChange",
     "Relationship",
     "RelationshipModel",
     "RelationshipAssociation",
+    "ScheduledJob",
+    "ScheduledJobs",
+    "Secret",
+    "SecretsGroup",
+    "SecretsGroupAssociation",
     "Status",
     "StatusField",
     "StatusModel",
