@@ -33,11 +33,18 @@ from nautobot.utilities.forms import (
     StaticSelect2,
     StaticSelect2Multiple,
     TagFilterField,
-    BOOLEAN_WITH_BLANK_CHOICES,
 )
+from nautobot.utilities.forms.constants import BOOLEAN_WITH_BLANK_CHOICES
 from nautobot.virtualization.models import Cluster, VirtualMachine, VMInterface
-from .choices import *
-from .constants import *
+from .choices import IPAddressFamilyChoices, IPAddressRoleChoices, ServiceProtocolChoices
+from .constants import (
+    IPADDRESS_MASK_LENGTH_MIN,
+    IPADDRESS_MASK_LENGTH_MAX,
+    PREFIX_LENGTH_MAX,
+    PREFIX_LENGTH_MIN,
+    SERVICE_PORT_MAX,
+    SERVICE_PORT_MIN,
+)
 from .models import (
     Aggregate,
     IPAddress,
@@ -213,8 +220,6 @@ class RIRForm(BootstrapMixin, CustomFieldModelForm, RelationshipModelForm):
 
 
 class RIRCSVForm(CustomFieldModelCSVForm):
-    slug = SlugField()
-
     class Meta:
         model = RIR
         fields = RIR.csv_headers
@@ -329,8 +334,6 @@ class RoleForm(BootstrapMixin, CustomFieldModelForm, RelationshipModelForm):
 
 
 class RoleCSVForm(CustomFieldModelCSVForm):
-    slug = SlugField()
-
     class Meta:
         model = Role
         fields = Role.csv_headers
@@ -997,7 +1000,6 @@ class VLANGroupCSVForm(CustomFieldModelCSVForm):
         to_field_name="name",
         help_text="Assigned site",
     )
-    slug = SlugField()
 
     class Meta:
         model = VLANGroup
